@@ -83,11 +83,15 @@ Readonly::Hash our %TYPE => (
 	'r' => 'Three-dimensional artifact or naturally occurring object',
 	't' => 'Manuscript language material',
 );
+Readonly::Hash our %TYPE_OF_CONTROL => (
+	' ' => 'No specified type',
+	'a' => 'Archival',
+);
 Readonly::Hash our %UNDEFINED => (
 	'0' => 'Undefined',
 );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -174,6 +178,12 @@ sub desc_type {
 	return $TYPE{$type_code};
 }
 
+sub desc_type_of_control {
+	my ($self, $type_of_control) = @_;
+
+	return $TYPE_OF_CONTROL{$type_of_control};
+}
+
 sub desc_undefined {
 	my ($self, $undefined) = @_;
 
